@@ -129,7 +129,7 @@ class mongo_operation:
 
 
     @ensure_annotations
-    def bulk_insert(self, dataframe:str,collection_name:str = None, **kwargs ):
+    def bulk_insert(self, dataframe:str or pd.DataFrame ,collection_name:str = None, **kwargs ):
         """ insert data from dataframe object / csv /excel file to mongodb
         
         ------
